        function getT(rr,cc){
       if(rr==2 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260524 a 12</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==2 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260524 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>43</strong> miembros: 30 <strong>control</strong><br>0,1,2,3,4,5,6,9,10,12,15,17,18,20,23,25,26,27,29,32,34,36,39,40,42,43,44,46,48,50';}
       if(rr==2 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260524 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>11</strong> miembros: 16 <br>8,11,14,16,19,21,22,24,28,30,31,33,35,38,47,49';}
       if(rr==2 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260524 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>7</strong> miembros: 5 <br>7,13,37,41,45';}
       if(rr==9 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260524 a 12</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==9 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260524 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>43</strong> miembros: 30 <strong>control</strong><br>0,1,2,3,4,5,6,9,10,12,15,17,18,20,23,25,26,27,29,32,34,36,39,40,42,43,44,46,48,50';}
       if(rr==9 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260524 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>11</strong> miembros: 16 <br>8,11,14,16,19,21,22,24,28,30,31,33,35,38,47,49';}
       if(rr==9 && cc==3){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260524 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>7</strong> miembros: 5 <br>7,13,37,41,45';}
       if(rr==10 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260524 a 12</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==10 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260524 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>43</strong> miembros: 30 <strong>control</strong><br>0,1,2,3,4,5,6,9,10,12,15,17,18,20,23,25,26,27,29,32,34,36,39,40,42,43,44,46,48,50';}
       if(rr==10 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260524 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>11</strong> miembros: 16 <br>8,11,14,16,19,21,22,24,28,30,31,33,35,38,47,49';}
       if(rr==10 && cc==3){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260524 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>7</strong> miembros: 5 <br>7,13,37,41,45';}
       if(rr==11 && cc==0){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260524 a 12</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==11 && cc==1){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260524 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>43</strong> miembros: 30 <strong>control</strong><br>0,1,2,3,4,5,6,9,10,12,15,17,18,20,23,25,26,27,29,32,34,36,39,40,42,43,44,46,48,50';}
       if(rr==11 && cc==2){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260524 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>11</strong> miembros: 16 <br>8,11,14,16,19,21,22,24,28,30,31,33,35,38,47,49';}
       if(rr==11 && cc==3){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260524 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>7</strong> miembros: 5 <br>7,13,37,41,45';}
       if(rr==12 && cc==0){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260524 a 12</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==12 && cc==1){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260524 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>43</strong> miembros: 30 <strong>control</strong><br>0,1,2,3,4,5,6,9,10,12,15,17,18,20,23,25,26,27,29,32,34,36,39,40,42,43,44,46,48,50';}
       if(rr==12 && cc==2){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260524 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>11</strong> miembros: 16 <br>8,11,14,16,19,21,22,24,28,30,31,33,35,38,47,49';}
       if(rr==12 && cc==3){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260524 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>7</strong> miembros: 5 <br>7,13,37,41,45';}
       if(rr==13 && cc==0){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260524 a 12</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==13 && cc==1){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260524 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>43</strong> miembros: 30 <strong>control</strong><br>0,1,2,3,4,5,6,9,10,12,15,17,18,20,23,25,26,27,29,32,34,36,39,40,42,43,44,46,48,50';}
       if(rr==13 && cc==2){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260524 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>11</strong> miembros: 16 <br>8,11,14,16,19,21,22,24,28,30,31,33,35,38,47,49';}
       if(rr==13 && cc==3){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260524 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>7</strong> miembros: 5 <br>7,13,37,41,45';}
       if(rr==14 && cc==0){return '<strong>Precipitacion de 00 a 12 UTC (mm)</strong><br><br><strong>20260524 a 12</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==14 && cc==1){return '<strong>Precipitacion de 00 a 12 UTC (mm)</strong><br><br><strong>20260524 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>43</strong> miembros: 30 <strong>control</strong><br>0,1,2,3,4,5,6,9,10,12,15,17,18,20,23,25,26,27,29,32,34,36,39,40,42,43,44,46,48,50';}
       if(rr==14 && cc==2){return '<strong>Precipitacion de 00 a 12 UTC (mm)</strong><br><br><strong>20260524 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>11</strong> miembros: 16 <br>8,11,14,16,19,21,22,24,28,30,31,33,35,38,47,49';}
       if(rr==14 && cc==3){return '<strong>Precipitacion de 00 a 12 UTC (mm)</strong><br><br><strong>20260524 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>7</strong> miembros: 5 <br>7,13,37,41,45';}
       if(rr==15 && cc==0){return '<strong>Nieve acumulada de 00 a 12 UTC (mm de agua equivalente)</strong><br><br><strong>20260524 a 12</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==15 && cc==1){return '<strong>Nieve acumulada de 00 a 12 UTC (mm de agua equivalente)</strong><br><br><strong>20260524 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>43</strong> miembros: 30 <strong>control</strong><br>0,1,2,3,4,5,6,9,10,12,15,17,18,20,23,25,26,27,29,32,34,36,39,40,42,43,44,46,48,50';}
       if(rr==15 && cc==2){return '<strong>Nieve acumulada de 00 a 12 UTC (mm de agua equivalente)</strong><br><br><strong>20260524 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>11</strong> miembros: 16 <br>8,11,14,16,19,21,22,24,28,30,31,33,35,38,47,49';}
       if(rr==15 && cc==3){return '<strong>Nieve acumulada de 00 a 12 UTC (mm de agua equivalente)</strong><br><br><strong>20260524 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>7</strong> miembros: 5 <br>7,13,37,41,45';}
       if(rr==16 && cc==0){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260524 a 12</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==16 && cc==1){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260524 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>43</strong> miembros: 30 <strong>control</strong><br>0,1,2,3,4,5,6,9,10,12,15,17,18,20,23,25,26,27,29,32,34,36,39,40,42,43,44,46,48,50';}
       if(rr==16 && cc==2){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260524 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>11</strong> miembros: 16 <br>8,11,14,16,19,21,22,24,28,30,31,33,35,38,47,49';}
       if(rr==16 && cc==3){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260524 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>7</strong> miembros: 5 <br>7,13,37,41,45';}
}
